@@ -4,7 +4,7 @@ use Tk ();
 use Tk::Toplevel;
 
 use vars qw($VERSION @ISA);
-$VERSION = substr(q$Revision: 2.18 $, 10) + 2 . "";
+$VERSION = substr(q$Revision: 2.20 $, 10) + 2 . "";
 
 @ISA = qw(Tk::Toplevel);
 
@@ -52,7 +52,7 @@ sub Populate
 
   [Cascade => '~View', -menuitems =>
    [
-    [Checkbutton => '~POD Tree', -variable => \$w->{Tree_on},
+    [Checkbutton => '~Pod Tree', -variable => \$w->{Tree_on},
      '-command' => sub { $w->tree($w->{Tree_on}) }],
     '-',
     [Button => "Zoom ~in",  -command => ['zoom_in', $p]],
@@ -87,7 +87,7 @@ sub Populate
    [
     # XXX restructure to not reference to tkpod
     [Button => '~Usage...',       -command => ['help', $w]],
-    [Button => '~Programming...', -command => sub { $w->parent->Pod(-file=>'Tk/Pod.pm') }],
+    [Button => '~Programming...', -command => sub { $w->parent->Pod(-file=>'Tk/Pod.pm', -exitbutton => $w->cget(-exitbutton)) }],
     [Button => '~About...', -command => ['about', $w]],
    ]
   ]
@@ -100,6 +100,7 @@ sub Populate
  $w->Delegates('Menubar' => $mbar);
  $w->ConfigSpecs(
     -tree => ['METHOD', 'tree', 'Tree', 0],
+    -exitbutton => ['PASSIVE', 'exitButton', 'ExitButton', $exitbutton],
     'DEFAULT' => [$p],
  );
 
@@ -119,12 +120,12 @@ sub openfile {
     my $file;
     if ($cw->can("getOpenFile")) {
 	$file = $cw->getOpenFile
-	    (-title => "Choose POD file",
+	    (-title => "Choose Pod file",
 	     -defaultextension => 'pod',
-	     -filetypes => [['POD containing files', ['*.pod',
+	     -filetypes => [['Pod containing files', ['*.pod',
 						      '*.pl',
 						      '*.pm']],
-			    ['POD files', '*.pod'],
+			    ['Pod files', '*.pod'],
 			    ['Perl scripts', '*.pl'],
 			    ['Perl modules', '*.pm'],
 			    ['All files', '*']]);
@@ -140,33 +141,52 @@ sub openfile {
 
 sub openpod {
     my($cw,$p) = @_;
-    my $t = $cw->Toplevel(-title => "Set POD");
+    my $t = $cw->Toplevel(-title => "Set Pod");
     $t->transient($cw);
     $t->grab;
-    $t->Label(-text => "POD:")->pack(-side => "left");
-    my $pod;
-    my $e = $t->Entry(-textvariable => \$pod)->pack(-side => "left");
-    $e->focus;
-    my $go = 0;
-    $e->bind("<Return>" => sub { $go = 1 });
-    $e->bind("<Escape>" => sub { $go = -1 });
-    $t->Button(-text => "OK",
-	       -command => sub { $go = 1 })->pack(-side => "left");
-    $t->Button(-text => "Cancel",
-	       -command => sub { $go = -1 })->pack(-side => "left");
+    my($pod, $e, $go);
+    {
+	my $f = $t->Frame->pack(-fill => "x");
+	$f->Label(-text => "Pod:")->pack(-side => "left");
+	$e = $f->Entry(-textvariable => \$pod)->pack(-side => "left", -fill => "x", -expand => 1);
+	$e->focus;
+	$go = 0;
+	$e->bind("<Return>" => sub { $go = 1 });
+	$e->bind("<Escape>" => sub { $go = -1 });
+    }
+
+    {
+	my $f = $t->Frame->pack;
+	$f->Button(-text => "OK",
+		   -command => sub { $go = 1 })->pack(-side => "left");
+	$f->Button(-text => "New window",
+		   -command => sub { $go = 2 })->pack(-side => "left");
+	$f->Button(-text => "Cancel",
+		   -command => sub { $go = -1 })->pack(-side => "left");
+    }
     $t->Popup(-popover => $cw);
     $t->OnDestroy(sub { $go = -1 unless $go });
     $t->waitVariable(\$go);
     $t->grabRelease;
     $t->destroy;
-    if ($go == 1 && $pod ne "") {
-	$cw->configure(-file => $pod);
+    if ($pod ne "") {
+	if ($go == 1) {
+	    $cw->configure(-file => $pod);
+	} elsif ($go == 2) {
+	    my $new_cw = $cw->MainWindow->Pod
+		('-tree' => $cw->cget(-tree),
+		 -exitbutton => $cw->cget(-exitbutton),
+		);
+	    $new_cw->configure('-file' => $pod);
+	}
     }
 }
 
 sub newwindow {
     my($cw) = @_;
-    $cw->MainWindow->Pod;
+    $cw->MainWindow->Pod('-tree' => $cw->cget(-tree),
+			 -exitbutton => $cw->cget(-exitbutton),
+			);
 }
 
 sub Dir {
@@ -180,7 +200,10 @@ sub Dir {
 sub quit { shift->destroy }
 
 sub help {
-    shift->parent->Pod(-file=>'Tk::Pod_usage.pod');
+    my $w = shift;
+    $w->parent->Pod(-file=>'Tk::Pod_usage.pod',
+		    -exitbutton => $w->cget(-exitbutton),
+		   );
 }
 
 sub about {
@@ -380,8 +403,10 @@ sub _configure_tree {
 	     my $e = $_[1];
 	     my $uri = $e->uri;
 	     if ($uri =~ /^file:(.*)/) {
-		 $w->MainWindow->Pod('-file' => $1,
-				     '-tree' => !!$tree);
+		 $w->MainWindow->Pod
+		     ('-file' => $1,
+		      -exitbutton => $w->cget(-exitbutton),
+		      '-tree' => !!$tree);
 	     } else {
 		 die "NYI";
 	     }
@@ -395,24 +420,24 @@ __END__
 
 =head1 NAME
 
-Tk::Pod - POD browser toplevel widget
+Tk::Pod - Pod browser toplevel widget
 
 
 =head1 SYNOPSIS
 
     use Tk::Pod
 
-    Tk::Pod->Dir(@dirs)			# add dirs to search path for POD
+    Tk::Pod->Dir(@dirs)			# add dirs to search path for Pod
 
     $pod = $parent->Pod(
-		-file = > $name,	# search and display POD for name
+		-file = > $name,	# search and display Pod for name
 		-tree = > $bool		# display pod file tree
 		);
 
 
 =head1 DESCRIPTION
 
-Simple POD browser with hypertext capabilities in a C<Toplevel> widget
+Simple Pod browser with hypertext capabilities in a C<Toplevel> widget
 
 =head1 OPTIONS
 
@@ -434,7 +459,7 @@ Other options are propagated to the embedded L<Tk::Pod::Text> widget.
 
 =head1 BUGS
 
-If you set C<-file> while creating the POD widget,
+If you set C<-file> while creating the Pod widget,
 
     $parent->Pod(-tree => 1, -file => $pod);
 
